#[repr(u8)]pub(crate) enum FragmentStatus {
New = 0,
StyleChanged = 1,
OnlyDescendantsChanged = 2,
Clean = 3,
}Variants
New = 0
This is a brand new fragment.
StyleChanged = 1
The style of the fragment has changed.
OnlyDescendantsChanged = 2
The fragment was reused between layouts, some descendant fragment may be different, but otherwise nothing has changed on the fragment itself.
Clean = 3
The fragment hasn’t changed.