pub(crate) struct BaseFragment {
pub tag: Option<Tag>,
pub flags: FragmentFlags,
rect: SyncPhysicalRectAu,
pub status: AtomicU8,
}Expand description
This data structure stores fields that are common to all non-base Fragment types and should generally be the first member of all concrete fragments.
Fields
tag: Option<Tag>A tag which identifies the DOM node and pseudo element of this Fragment’s content. If this fragment is for an anonymous box, the tag will be None.
flags: FragmentFlagsFlags which various information about this fragment used during layout.
rect: SyncPhysicalRectAuThe content rect of this fragment in the parent fragment’s content rectangle. This does not include padding, border, or margin – it only includes content. This is relative to the parent containing block.
status: AtomicU8A FragmentStatus used to track fragment reuse when collecting reflow statistics.
Implementations
Sourceimpl BaseFragment
impl BaseFragment
fn visit_fragment(&self, builder: &mut DisplayListBuilder<'_>)
Sourceimpl BaseFragment
impl BaseFragment
pub(crate) fn new( base_fragment_info: BaseFragmentInfo, rect: PhysicalRect<Au>, ) -> Self
pub(crate) fn rect(&self) -> PhysicalRect<Au>
pub(crate) fn set_rect(&self, new_rect: PhysicalRect<Au>)
pub(crate) fn translate_rect(&self, offset: PhysicalSize<Au>)
pub(crate) fn set_rect_origin(&self, offset: PhysicalPoint<Au>)
pub(crate) fn is_anonymous(&self) -> bool
pub(crate) fn status(&self) -> FragmentStatus
pub(crate) fn set_status(&self, new_status: FragmentStatus)