pub(crate) struct BaseFragment {
pub tag: Option<Tag>,
pub flags: FragmentFlags,
pub style: BaseFragmentStyle,
pub rect: PhysicalRect<Au>,
pub status: FragmentStatus,
}Expand description
This data structure stores fields that are common to all non-base Fragment types and should generally be the first member of all concrete fragments.
Fields
tag: Option<Tag>A tag which identifies the DOM node and pseudo element of this Fragment’s content. If this fragment is for an anonymous box, the tag will be None.
flags: FragmentFlagsFlags which various information about this fragment used during layout.
style: BaseFragmentStyleThe style for this BaseFragment. Depending on the fragment type this is either
a shared or non-shared style.
rect: PhysicalRect<Au>The content rect of this fragment in the parent fragment’s content rectangle. This does not include padding, border, or margin – it only includes content. This is relative to the parent containing block.
status: FragmentStatusA FragmentStatus used to track fragment reuse when collecting reflow statistics.
Implementations
Sourceimpl BaseFragment
impl BaseFragment
pub(crate) fn new( base_fragment_info: BaseFragmentInfo, style: BaseFragmentStyle, rect: PhysicalRect<Au>, ) -> Self
pub(crate) fn is_anonymous(&self) -> bool
pub(crate) fn repair_style(&mut self, style: &ServoArc<ComputedValues>)
pub(crate) fn style<'a>(&'a self) -> BaseFragmentStyleRef<'a>